using FitConnect.Models;
using FitConnect.Models.v1.Api;
using FitConnect.Services.Models.v1.Submission;

namespace FitConnect.Interfaces.Subscriber;

public interface ISubscriber : IFitConnectClient {
    /// <summary>
    ///     Loads a list of available Submissions that were submitted to the subscriber.
    /// </summary>
    /// <param name="destinationId">unique identifier of the destination</param>
    /// <param name="offset">How many entries of the result should be skipped</param>
    /// <param name="limit">How many result sets should be loaded</param>
    /// <returns>List of available submissions for pickup</returns>
    public Task<IEnumerable<SubmissionForPickup>> GetAvailableSubmissionsAsync(
        Guid destinationId,
        int offset = 0, int limit = 100);

    /// <summary>
    ///     Loads a single Submission by id.
    /// </summary>
    /// <param name="submissionId">unique identifier of a <see cref="Submission" /></param>
    /// <returns>A subscriber object with a submission</returns>
    public Task<IReceivedSubmission> RequestSubmissionAsync(Guid submissionId);

    /// <summary>
    ///     Loads a single Submission.
    /// </summary>
    /// <param name="submission"></param>
    /// <returns>A subscriber object with a submission</returns>
    public Task<IReceivedSubmission> RequestSubmissionAsync(SubmissionForPickup submission);

    /// <summary>
    ///     Rejecting a submission
    /// </summary>
    /// <param name="submission"></param>
    /// <param name="problem"></param>
    /// <param name="problems">At least one problem is needed</param>
    /// <returns></returns>
    public Task RejectSubmissionAsync(ISubmissionBody submission, Problems problem,
        params Problems[] problems);

    /// <summary>
    /// Returns the status of a submission
    /// </summary>
    /// <param name="destinationId"></param>
    /// <param name="caseId"></param>
    /// <param name="submissionId"></param>
    Task<SubmissionStatus> GetStatusForSubmission(Guid destinationId, Guid caseId,
        Guid submissionId);
}
